@@ -156,6 +156,11 @@ override _build_config => sub
     $config->{'AppKit'}->{'password_force_numerics'} = 0;
     $config->{'AppKit'}->{'password_force_symbols'}  = 0;
     
+    # unbuffer stdout and stderr to prevent logging 
+    # getting clogged up.
+    select( ( select(\*STDERR), $|=1 )[0] );
+    select( ( select(\*STDOUT), $|=1 )[0] );
+
     # NOTE: if you want to use Memcahced in your app add this to your builder,
     #
     # $config->{'Plugin::Cache'}{backend} = {
@@ -184,7 +189,7 @@ OpusVL::AppKit::Builder
 
 =head1 VERSION
 
-version 2.22
+version 2.23
 
 =head1 SYNOPSIS
 
